import * as cdk from '@aws-cdk/core';
/**
 * Schema for Module Fragment of type JFrog::Artifactory::ExistingVpc::MODULE.
 *
 * @schema CfnModuleProps
 */
export interface CfnModuleProps {
    /**
     * @schema CfnModuleProps#Parameters
     */
    readonly parameters?: CfnModulePropsParameters;
    /**
     * @schema CfnModuleProps#Resources
     */
    readonly resources?: CfnModulePropsResources;
}
/**
 * Converts an object of type 'CfnModuleProps' to JSON representation.
 */
export declare function toJson_CfnModuleProps(obj: CfnModuleProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsParameters
 */
export interface CfnModulePropsParameters {
    /**
     * Logical Id of the MODULE.
     *
     * @schema CfnModulePropsParameters#LogicalId
     */
    readonly logicalId?: CfnModulePropsParametersLogicalId;
    /**
     * Availability Zone 1 to use for the subnets in the VPC.
     *
     * Two Availability Zones are used for this deployment.
     *
     * @schema CfnModulePropsParameters#AvailabilityZone1
     */
    readonly availabilityZone1?: CfnModulePropsParametersAvailabilityZone1;
    /**
     * Availability Zone 2 to use for the subnets in the VPC.
     *
     * Two Availability Zones are used for this deployment.
     *
     * @schema CfnModulePropsParameters#AvailabilityZone2
     */
    readonly availabilityZone2?: CfnModulePropsParametersAvailabilityZone2;
    /**
     * Name of an existing key pair, which allows you to connect securely to your instance after it launches.
     *
     * This is the key pair you created in your preferred Region.
     *
     * @schema CfnModulePropsParameters#KeyPairName
     */
    readonly keyPairName?: CfnModulePropsParametersKeyPairName;
    /**
     * ID of your existing VPC (e.g., vpc-0343606e).
     *
     * @schema CfnModulePropsParameters#VpcId
     */
    readonly vpcId?: CfnModulePropsParametersVpcId;
    /**
     * CIDR block for the VPC.
     *
     * @schema CfnModulePropsParameters#VpcCidr
     */
    readonly vpcCidr?: CfnModulePropsParametersVpcCidr;
    /**
     * ID of the private subnet in Availability Zone 2 of your existing VPC (e.g., subnet-z0376dab).
     *
     * @schema CfnModulePropsParameters#PrivateSubnet2Id
     */
    readonly privateSubnet2Id?: CfnModulePropsParametersPrivateSubnet2Id;
    /**
     * ID of the private subnet in Availability Zone 1 of your existing VPC (e.g., subnet-z0376dab).
     *
     * @schema CfnModulePropsParameters#PrivateSubnet1Id
     */
    readonly privateSubnet1Id?: CfnModulePropsParametersPrivateSubnet1Id;
    /**
     * ID of the public subnet in Availability Zone 1 of your existing VPC (e.g., subnet-z0376dab).
     *
     * @schema CfnModulePropsParameters#PublicSubnet1Id
     */
    readonly publicSubnet1Id?: CfnModulePropsParametersPublicSubnet1Id;
    /**
     * ID of the public subnet in Availability Zone 1 of your existing VPC (e.g., subnet-z0376dab).
     *
     * @schema CfnModulePropsParameters#PublicSubnet2Id
     */
    readonly publicSubnet2Id?: CfnModulePropsParametersPublicSubnet2Id;
    /**
     * CIDR of the private subnet in Availability Zone 1 of your existing VPC (e.g., 10.0.0.0/19).
     *
     * @schema CfnModulePropsParameters#PrivateSubnet1Cidr
     */
    readonly privateSubnet1Cidr?: CfnModulePropsParametersPrivateSubnet1Cidr;
    /**
     * CIDR of the private subnet in Availability Zone 2 of your existing VPC (e.g., 10.0.32.0/19).
     *
     * @schema CfnModulePropsParameters#PrivateSubnet2Cidr
     */
    readonly privateSubnet2Cidr?: CfnModulePropsParametersPrivateSubnet2Cidr;
    /**
     * CIDR IP range that is permitted to access Artifactory.
     *
     * We recommend that you set this value to a trusted IP range. For example, you might want to grant only your corporate network access to the software.
     *
     * @schema CfnModulePropsParameters#AccessCidr
     */
    readonly accessCidr?: CfnModulePropsParametersAccessCidr;
    /**
     * Remote CIDR range that allows you to connect to the bastion instance by using SSH.
     *
     * We recommend that you set this value to a trusted IP range. For example, you might want to grant specific ranges inside your corporate network SSH access.
     *
     * @schema CfnModulePropsParameters#RemoteAccessCidr
     */
    readonly remoteAccessCidr?: CfnModulePropsParametersRemoteAccessCidr;
    /**
     * Choose whether this is internet facing or internal.
     *
     * @schema CfnModulePropsParameters#ELBScheme
     */
    readonly elbScheme?: CfnModulePropsParametersElbScheme;
    /**
     * If set to true, a bastion host will be created.
     *
     * @schema CfnModulePropsParameters#EnableBastion
     */
    readonly enableBastion?: CfnModulePropsParametersEnableBastion;
    /**
     * Size of the bastion instances.
     *
     * @schema CfnModulePropsParameters#BastionInstanceType
     */
    readonly bastionInstanceType?: CfnModulePropsParametersBastionInstanceType;
    /**
     * Size of the root volume on the bastion instances.
     *
     * @schema CfnModulePropsParameters#BastionRootVolumeSize
     */
    readonly bastionRootVolumeSize?: CfnModulePropsParametersBastionRootVolumeSize;
    /**
     * Choose whether to enable TCPForwarding via the bootstrapping of the bastion instance or not.
     *
     * @schema CfnModulePropsParameters#BastionEnableTcpForwarding
     */
    readonly bastionEnableTcpForwarding?: CfnModulePropsParametersBastionEnableTcpForwarding;
    /**
     * Choose true to enable X11 via the bootstrapping of the bastion host.
     *
     * Setting this value to true will enable X Windows over SSH. X11 forwarding can be useful, but it is also a security risk, so it's recommended that you keep the default (false) setting.
     *
     * @schema CfnModulePropsParameters#BastionEnableX11Forwarding
     */
    readonly bastionEnableX11Forwarding?: CfnModulePropsParametersBastionEnableX11Forwarding;
    /**
     * Linux distribution for the Amazon Machine Image (AMI) to be used for the bastion instances.
     *
     * @schema CfnModulePropsParameters#BastionOs
     */
    readonly bastionOs?: CfnModulePropsParametersBastionOs;
    /**
     * Number of bastion instances to create.
     *
     * @schema CfnModulePropsParameters#NumBastionHosts
     */
    readonly numBastionHosts?: CfnModulePropsParametersNumBastionHosts;
    /**
     * Size in gigabytes of the available storage (min 10GB);
     *
     * the Quick Start will create an Amazon Elastic Block Store (Amazon EBS) volumes of this size.
     *
     * @schema CfnModulePropsParameters#VolumeSize
     */
    readonly volumeSize?: CfnModulePropsParametersVolumeSize;
    /**
     * EC2 type for the Artifactory instances.
     *
     * @schema CfnModulePropsParameters#InstanceType
     */
    readonly instanceType?: CfnModulePropsParametersInstanceType;
    /**
     * Number of secondary Artifactory servers to complete your HA deployment.
     *
     * To align with Artifactory best practices, the minimum number is two and the maximum is seven. Do not select more instances than you have licenses for.
     *
     * @schema CfnModulePropsParameters#NumberOfSecondary
     */
    readonly numberOfSecondary?: CfnModulePropsParametersNumberOfSecondary;
    /**
     * JFrog Artifactory product you want to install into an AMI.
     *
     * @schema CfnModulePropsParameters#ArtifactoryProduct
     */
    readonly artifactoryProduct?: CfnModulePropsParametersArtifactoryProduct;
    /**
     * Version of Artifactory that you want to deploy into the Quick Start.
     *
     * See the release notes to select the version you want to deploy at https://www.jfrog.com/confluence/display/RTF/Release+Notes.
     *
     * @schema CfnModulePropsParameters#ArtifactoryVersion
     */
    readonly artifactoryVersion?: CfnModulePropsParametersArtifactoryVersion;
    /**
     * Secret name created in AWS Secrets Manager, which contains the Artifactory licenses.
     *
     * @schema CfnModulePropsParameters#SmLicenseName
     */
    readonly smLicenseName?: CfnModulePropsParametersSmLicenseName;
    /**
     * Secret name created in AWS Secrets Manager, which contains the SSL certificate and certificate key.
     *
     * @schema CfnModulePropsParameters#SmCertName
     */
    readonly smCertName?: CfnModulePropsParametersSmCertName;
    /**
     * Name of your Artifactory server.
     *
     * Ensure that this matches your certificate.
     *
     * @schema CfnModulePropsParameters#ArtifactoryServerName
     */
    readonly artifactoryServerName?: CfnModulePropsParametersArtifactoryServerName;
    /**
     * Master key for the Artifactory cluster.
     *
     * Generate a master key by using the command '$openssl rand -hex 16'.
     *
     * @schema CfnModulePropsParameters#MasterKey
     */
    readonly masterKey?: CfnModulePropsParametersMasterKey;
    /**
     * Set Java options to pass to the JVM for Artifactory.
     *
     * For more information, see the Artifactory system requirements at https://www.jfrog.com/confluence/display/RTF/System+Requirements#SystemRequirements-RecommendedHardware. Do not add Xms or Xmx settings without disabling DefaultJavaMemSettings.
     *
     * @schema CfnModulePropsParameters#ExtraJavaOptions
     */
    readonly extraJavaOptions?: CfnModulePropsParametersExtraJavaOptions;
    /**
     * Choose false to overwrite the standard memory-calculation options to pass to the Artifactory JVM.
     *
     * If you plan to overwrite them, ensure they are added to the ExtraJavaOptions to prevent the stack provision from failing.
     *
     * @schema CfnModulePropsParameters#DefaultJavaMemSettings
     */
    readonly defaultJavaMemSettings?: CfnModulePropsParametersDefaultJavaMemSettings;
    /**
     * Name of your database instance.
     *
     * The name must be unique across all instances owned by your AWS account in the current Region. The database instance identifier is case-insensitive, but it's stored in lowercase (as in "mydbinstance").
     *
     * @schema CfnModulePropsParameters#DatabaseName
     */
    readonly databaseName?: CfnModulePropsParametersDatabaseName;
    /**
     * Database engine that you want to run, which is currently locked to MySQL.
     *
     * @schema CfnModulePropsParameters#DatabaseEngine
     */
    readonly databaseEngine?: CfnModulePropsParametersDatabaseEngine;
    /**
     * Login ID for the master user of your database instance.
     *
     * @schema CfnModulePropsParameters#DatabaseUser
     */
    readonly databaseUser?: CfnModulePropsParametersDatabaseUser;
    /**
     * Password for the Artifactory database user.
     *
     * @schema CfnModulePropsParameters#DatabasePassword
     */
    readonly databasePassword?: CfnModulePropsParametersDatabasePassword;
    /**
     * Size of the database to be deployed as part of the Quick Start.
     *
     * @schema CfnModulePropsParameters#DatabaseInstance
     */
    readonly databaseInstance?: CfnModulePropsParametersDatabaseInstance;
    /**
     * Size in gigabytes of the available storage for the database instance.
     *
     * @schema CfnModulePropsParameters#DatabaseAllocatedStorage
     */
    readonly databaseAllocatedStorage?: CfnModulePropsParametersDatabaseAllocatedStorage;
    /**
     * Preferred availability zone for Amazon RDS primary instance.
     *
     * @schema CfnModulePropsParameters#DatabasePreferredAz
     */
    readonly databasePreferredAz?: CfnModulePropsParametersDatabasePreferredAz;
    /**
     * Choose false to create an Amazon RDS instance in a single Availability Zone.
     *
     * @schema CfnModulePropsParameters#MultiAzDatabase
     */
    readonly multiAzDatabase?: CfnModulePropsParametersMultiAzDatabase;
    /**
     * S3 bucket name for the Quick Start assets.
     *
     * This string can include numbers, lowercase letters, and hyphens (-). It cannot start or end with a hyphen (-).
     *
     * @schema CfnModulePropsParameters#QsS3BucketName
     */
    readonly qsS3BucketName?: CfnModulePropsParametersQsS3BucketName;
    /**
     * S3 key prefix for the Quick Start assets.
     *
     * Quick Start key prefix can include numbers, lowercase letters, uppercase letters, hyphens (-), and forward slash (/).
     *
     * @schema CfnModulePropsParameters#QsS3KeyPrefix
     */
    readonly qsS3KeyPrefix?: CfnModulePropsParametersQsS3KeyPrefix;
    /**
     * AWS Region where the Quick Start S3 bucket (QSS3BucketName) is hosted.
     *
     * If you use your own bucket, you must specify your own value.
     *
     * @schema CfnModulePropsParameters#QsS3BucketRegion
     */
    readonly qsS3BucketRegion?: CfnModulePropsParametersQsS3BucketRegion;
    /**
     * Choose true to install JFrog Xray instance(s).
     *
     * @schema CfnModulePropsParameters#InstallXray
     */
    readonly installXray?: CfnModulePropsParametersInstallXray;
    /**
     * The version of Xray that you want to deploy into the Quick Start.
     *
     * @schema CfnModulePropsParameters#XrayVersion
     */
    readonly xrayVersion?: CfnModulePropsParametersXrayVersion;
    /**
     * The number of Xray instances servers to complete your HA deployment.
     *
     * The minimum number is one; the maximum is seven. Do not select more than instances than you have licenses for.
     *
     * @schema CfnModulePropsParameters#XrayNumberOfInstances
     */
    readonly xrayNumberOfInstances?: CfnModulePropsParametersXrayNumberOfInstances;
    /**
     * The EC2 instance type for the Xray instances.
     *
     * @schema CfnModulePropsParameters#XrayInstanceType
     */
    readonly xrayInstanceType?: CfnModulePropsParametersXrayInstanceType;
    /**
     * The login ID for the Xray database user.
     *
     * @schema CfnModulePropsParameters#XrayDatabaseUser
     */
    readonly xrayDatabaseUser?: CfnModulePropsParametersXrayDatabaseUser;
    /**
     * The password for the Xray database user.
     *
     * @schema CfnModulePropsParameters#XrayDatabasePassword
     */
    readonly xrayDatabasePassword?: CfnModulePropsParametersXrayDatabasePassword;
}
/**
 * Converts an object of type 'CfnModulePropsParameters' to JSON representation.
 */
export declare function toJson_CfnModulePropsParameters(obj: CfnModulePropsParameters | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResources
 */
export interface CfnModulePropsResources {
    /**
     * @schema CfnModulePropsResources#BastionStack
     */
    readonly bastionStack?: CfnModulePropsResourcesBastionStack;
    /**
     * @schema CfnModulePropsResources#ArtifactoryCoreInfraStack
     */
    readonly artifactoryCoreInfraStack?: CfnModulePropsResourcesArtifactoryCoreInfraStack;
    /**
     * @schema CfnModulePropsResources#ArtifactoryElb
     */
    readonly artifactoryElb?: CfnModulePropsResourcesArtifactoryElb;
    /**
     * @schema CfnModulePropsResources#ArtifactorySslTargetGroup
     */
    readonly artifactorySslTargetGroup?: CfnModulePropsResourcesArtifactorySslTargetGroup;
    /**
     * @schema CfnModulePropsResources#ArtifactoryTargetGroup
     */
    readonly artifactoryTargetGroup?: CfnModulePropsResourcesArtifactoryTargetGroup;
    /**
     * @schema CfnModulePropsResources#ArtifactorySslElbListener
     */
    readonly artifactorySslElbListener?: CfnModulePropsResourcesArtifactorySslElbListener;
    /**
     * @schema CfnModulePropsResources#ArtifactoryElbListener
     */
    readonly artifactoryElbListener?: CfnModulePropsResourcesArtifactoryElbListener;
    /**
     * @schema CfnModulePropsResources#ArtifactoryInternalElb
     */
    readonly artifactoryInternalElb?: CfnModulePropsResourcesArtifactoryInternalElb;
    /**
     * @schema CfnModulePropsResources#ArtifactoryInternalTargetGroup
     */
    readonly artifactoryInternalTargetGroup?: CfnModulePropsResourcesArtifactoryInternalTargetGroup;
    /**
     * @schema CfnModulePropsResources#ArtifactoryInternalElbListener
     */
    readonly artifactoryInternalElbListener?: CfnModulePropsResourcesArtifactoryInternalElbListener;
    /**
     * @schema CfnModulePropsResources#ArtifactoryEc2Sg
     */
    readonly artifactoryEc2Sg?: CfnModulePropsResourcesArtifactoryEc2Sg;
    /**
     * @schema CfnModulePropsResources#ArtifactoryHostRole
     */
    readonly artifactoryHostRole?: CfnModulePropsResourcesArtifactoryHostRole;
    /**
     * @schema CfnModulePropsResources#ArtifactoryHostProfile
     */
    readonly artifactoryHostProfile?: CfnModulePropsResourcesArtifactoryHostProfile;
    /**
     * @schema CfnModulePropsResources#ArtifactoryPrimary
     */
    readonly artifactoryPrimary?: CfnModulePropsResourcesArtifactoryPrimary;
    /**
     * @schema CfnModulePropsResources#ArtifactorySecondary
     */
    readonly artifactorySecondary?: CfnModulePropsResourcesArtifactorySecondary;
    /**
     * @schema CfnModulePropsResources#XrayHostRole
     */
    readonly xrayHostRole?: CfnModulePropsResourcesXrayHostRole;
    /**
     * @schema CfnModulePropsResources#XrayHostProfile
     */
    readonly xrayHostProfile?: CfnModulePropsResourcesXrayHostProfile;
    /**
     * @schema CfnModulePropsResources#XrayExistingVpcStack
     */
    readonly xrayExistingVpcStack?: CfnModulePropsResourcesXrayExistingVpcStack;
}
/**
 * Converts an object of type 'CfnModulePropsResources' to JSON representation.
 */
export declare function toJson_CfnModulePropsResources(obj: CfnModulePropsResources | undefined): Record<string, any> | undefined;
/**
 * Logical Id of the MODULE.
 *
 * @schema CfnModulePropsParametersLogicalId
 */
export interface CfnModulePropsParametersLogicalId {
    /**
     * @schema CfnModulePropsParametersLogicalId#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersLogicalId#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersLogicalId' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersLogicalId(obj: CfnModulePropsParametersLogicalId | undefined): Record<string, any> | undefined;
/**
 * Availability Zone 1 to use for the subnets in the VPC.
 *
 * Two Availability Zones are used for this deployment.
 *
 * @schema CfnModulePropsParametersAvailabilityZone1
 */
export interface CfnModulePropsParametersAvailabilityZone1 {
    /**
     * @schema CfnModulePropsParametersAvailabilityZone1#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersAvailabilityZone1#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersAvailabilityZone1' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersAvailabilityZone1(obj: CfnModulePropsParametersAvailabilityZone1 | undefined): Record<string, any> | undefined;
/**
 * Availability Zone 2 to use for the subnets in the VPC.
 *
 * Two Availability Zones are used for this deployment.
 *
 * @schema CfnModulePropsParametersAvailabilityZone2
 */
export interface CfnModulePropsParametersAvailabilityZone2 {
    /**
     * @schema CfnModulePropsParametersAvailabilityZone2#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersAvailabilityZone2#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersAvailabilityZone2' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersAvailabilityZone2(obj: CfnModulePropsParametersAvailabilityZone2 | undefined): Record<string, any> | undefined;
/**
 * Name of an existing key pair, which allows you to connect securely to your instance after it launches.
 *
 * This is the key pair you created in your preferred Region.
 *
 * @schema CfnModulePropsParametersKeyPairName
 */
export interface CfnModulePropsParametersKeyPairName {
    /**
     * @schema CfnModulePropsParametersKeyPairName#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersKeyPairName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersKeyPairName' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersKeyPairName(obj: CfnModulePropsParametersKeyPairName | undefined): Record<string, any> | undefined;
/**
 * ID of your existing VPC (e.g., vpc-0343606e).
 *
 * @schema CfnModulePropsParametersVpcId
 */
export interface CfnModulePropsParametersVpcId {
    /**
     * @schema CfnModulePropsParametersVpcId#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersVpcId#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersVpcId' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersVpcId(obj: CfnModulePropsParametersVpcId | undefined): Record<string, any> | undefined;
/**
 * CIDR block for the VPC.
 *
 * @schema CfnModulePropsParametersVpcCidr
 */
export interface CfnModulePropsParametersVpcCidr {
    /**
     * @schema CfnModulePropsParametersVpcCidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersVpcCidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersVpcCidr' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersVpcCidr(obj: CfnModulePropsParametersVpcCidr | undefined): Record<string, any> | undefined;
/**
 * ID of the private subnet in Availability Zone 2 of your existing VPC (e.g., subnet-z0376dab).
 *
 * @schema CfnModulePropsParametersPrivateSubnet2Id
 */
export interface CfnModulePropsParametersPrivateSubnet2Id {
    /**
     * @schema CfnModulePropsParametersPrivateSubnet2Id#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersPrivateSubnet2Id#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersPrivateSubnet2Id' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersPrivateSubnet2Id(obj: CfnModulePropsParametersPrivateSubnet2Id | undefined): Record<string, any> | undefined;
/**
 * ID of the private subnet in Availability Zone 1 of your existing VPC (e.g., subnet-z0376dab).
 *
 * @schema CfnModulePropsParametersPrivateSubnet1Id
 */
export interface CfnModulePropsParametersPrivateSubnet1Id {
    /**
     * @schema CfnModulePropsParametersPrivateSubnet1Id#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersPrivateSubnet1Id#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersPrivateSubnet1Id' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersPrivateSubnet1Id(obj: CfnModulePropsParametersPrivateSubnet1Id | undefined): Record<string, any> | undefined;
/**
 * ID of the public subnet in Availability Zone 1 of your existing VPC (e.g., subnet-z0376dab).
 *
 * @schema CfnModulePropsParametersPublicSubnet1Id
 */
export interface CfnModulePropsParametersPublicSubnet1Id {
    /**
     * @schema CfnModulePropsParametersPublicSubnet1Id#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersPublicSubnet1Id#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersPublicSubnet1Id' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersPublicSubnet1Id(obj: CfnModulePropsParametersPublicSubnet1Id | undefined): Record<string, any> | undefined;
/**
 * ID of the public subnet in Availability Zone 1 of your existing VPC (e.g., subnet-z0376dab).
 *
 * @schema CfnModulePropsParametersPublicSubnet2Id
 */
export interface CfnModulePropsParametersPublicSubnet2Id {
    /**
     * @schema CfnModulePropsParametersPublicSubnet2Id#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersPublicSubnet2Id#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersPublicSubnet2Id' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersPublicSubnet2Id(obj: CfnModulePropsParametersPublicSubnet2Id | undefined): Record<string, any> | undefined;
/**
 * CIDR of the private subnet in Availability Zone 1 of your existing VPC (e.g., 10.0.0.0/19).
 *
 * @schema CfnModulePropsParametersPrivateSubnet1Cidr
 */
export interface CfnModulePropsParametersPrivateSubnet1Cidr {
    /**
     * @schema CfnModulePropsParametersPrivateSubnet1Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersPrivateSubnet1Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersPrivateSubnet1Cidr' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersPrivateSubnet1Cidr(obj: CfnModulePropsParametersPrivateSubnet1Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR of the private subnet in Availability Zone 2 of your existing VPC (e.g., 10.0.32.0/19).
 *
 * @schema CfnModulePropsParametersPrivateSubnet2Cidr
 */
export interface CfnModulePropsParametersPrivateSubnet2Cidr {
    /**
     * @schema CfnModulePropsParametersPrivateSubnet2Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersPrivateSubnet2Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersPrivateSubnet2Cidr' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersPrivateSubnet2Cidr(obj: CfnModulePropsParametersPrivateSubnet2Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR IP range that is permitted to access Artifactory.
 *
 * We recommend that you set this value to a trusted IP range. For example, you might want to grant only your corporate network access to the software.
 *
 * @schema CfnModulePropsParametersAccessCidr
 */
export interface CfnModulePropsParametersAccessCidr {
    /**
     * @schema CfnModulePropsParametersAccessCidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersAccessCidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersAccessCidr' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersAccessCidr(obj: CfnModulePropsParametersAccessCidr | undefined): Record<string, any> | undefined;
/**
 * Remote CIDR range that allows you to connect to the bastion instance by using SSH.
 *
 * We recommend that you set this value to a trusted IP range. For example, you might want to grant specific ranges inside your corporate network SSH access.
 *
 * @schema CfnModulePropsParametersRemoteAccessCidr
 */
export interface CfnModulePropsParametersRemoteAccessCidr {
    /**
     * @schema CfnModulePropsParametersRemoteAccessCidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersRemoteAccessCidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersRemoteAccessCidr' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersRemoteAccessCidr(obj: CfnModulePropsParametersRemoteAccessCidr | undefined): Record<string, any> | undefined;
/**
 * Choose whether this is internet facing or internal.
 *
 * @schema CfnModulePropsParametersElbScheme
 */
export interface CfnModulePropsParametersElbScheme {
    /**
     * @schema CfnModulePropsParametersElbScheme#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersElbScheme#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersElbScheme' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersElbScheme(obj: CfnModulePropsParametersElbScheme | undefined): Record<string, any> | undefined;
/**
 * If set to true, a bastion host will be created.
 *
 * @schema CfnModulePropsParametersEnableBastion
 */
export interface CfnModulePropsParametersEnableBastion {
    /**
     * @schema CfnModulePropsParametersEnableBastion#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersEnableBastion#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersEnableBastion' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersEnableBastion(obj: CfnModulePropsParametersEnableBastion | undefined): Record<string, any> | undefined;
/**
 * Size of the bastion instances.
 *
 * @schema CfnModulePropsParametersBastionInstanceType
 */
export interface CfnModulePropsParametersBastionInstanceType {
    /**
     * @schema CfnModulePropsParametersBastionInstanceType#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersBastionInstanceType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersBastionInstanceType' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersBastionInstanceType(obj: CfnModulePropsParametersBastionInstanceType | undefined): Record<string, any> | undefined;
/**
 * Size of the root volume on the bastion instances.
 *
 * @schema CfnModulePropsParametersBastionRootVolumeSize
 */
export interface CfnModulePropsParametersBastionRootVolumeSize {
    /**
     * @schema CfnModulePropsParametersBastionRootVolumeSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersBastionRootVolumeSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersBastionRootVolumeSize' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersBastionRootVolumeSize(obj: CfnModulePropsParametersBastionRootVolumeSize | undefined): Record<string, any> | undefined;
/**
 * Choose whether to enable TCPForwarding via the bootstrapping of the bastion instance or not.
 *
 * @schema CfnModulePropsParametersBastionEnableTcpForwarding
 */
export interface CfnModulePropsParametersBastionEnableTcpForwarding {
    /**
     * @schema CfnModulePropsParametersBastionEnableTcpForwarding#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersBastionEnableTcpForwarding#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersBastionEnableTcpForwarding' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersBastionEnableTcpForwarding(obj: CfnModulePropsParametersBastionEnableTcpForwarding | undefined): Record<string, any> | undefined;
/**
 * Choose true to enable X11 via the bootstrapping of the bastion host.
 *
 * Setting this value to true will enable X Windows over SSH. X11 forwarding can be useful, but it is also a security risk, so it's recommended that you keep the default (false) setting.
 *
 * @schema CfnModulePropsParametersBastionEnableX11Forwarding
 */
export interface CfnModulePropsParametersBastionEnableX11Forwarding {
    /**
     * @schema CfnModulePropsParametersBastionEnableX11Forwarding#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersBastionEnableX11Forwarding#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersBastionEnableX11Forwarding' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersBastionEnableX11Forwarding(obj: CfnModulePropsParametersBastionEnableX11Forwarding | undefined): Record<string, any> | undefined;
/**
 * Linux distribution for the Amazon Machine Image (AMI) to be used for the bastion instances.
 *
 * @schema CfnModulePropsParametersBastionOs
 */
export interface CfnModulePropsParametersBastionOs {
    /**
     * @schema CfnModulePropsParametersBastionOs#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersBastionOs#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersBastionOs' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersBastionOs(obj: CfnModulePropsParametersBastionOs | undefined): Record<string, any> | undefined;
/**
 * Number of bastion instances to create.
 *
 * @schema CfnModulePropsParametersNumBastionHosts
 */
export interface CfnModulePropsParametersNumBastionHosts {
    /**
     * @schema CfnModulePropsParametersNumBastionHosts#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersNumBastionHosts#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersNumBastionHosts' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersNumBastionHosts(obj: CfnModulePropsParametersNumBastionHosts | undefined): Record<string, any> | undefined;
/**
 * Size in gigabytes of the available storage (min 10GB);
 *
 * the Quick Start will create an Amazon Elastic Block Store (Amazon EBS) volumes of this size.
 *
 * @schema CfnModulePropsParametersVolumeSize
 */
export interface CfnModulePropsParametersVolumeSize {
    /**
     * @schema CfnModulePropsParametersVolumeSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersVolumeSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersVolumeSize' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersVolumeSize(obj: CfnModulePropsParametersVolumeSize | undefined): Record<string, any> | undefined;
/**
 * EC2 type for the Artifactory instances.
 *
 * @schema CfnModulePropsParametersInstanceType
 */
export interface CfnModulePropsParametersInstanceType {
    /**
     * @schema CfnModulePropsParametersInstanceType#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersInstanceType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersInstanceType' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersInstanceType(obj: CfnModulePropsParametersInstanceType | undefined): Record<string, any> | undefined;
/**
 * Number of secondary Artifactory servers to complete your HA deployment.
 *
 * To align with Artifactory best practices, the minimum number is two and the maximum is seven. Do not select more instances than you have licenses for.
 *
 * @schema CfnModulePropsParametersNumberOfSecondary
 */
export interface CfnModulePropsParametersNumberOfSecondary {
    /**
     * @schema CfnModulePropsParametersNumberOfSecondary#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersNumberOfSecondary#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersNumberOfSecondary' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersNumberOfSecondary(obj: CfnModulePropsParametersNumberOfSecondary | undefined): Record<string, any> | undefined;
/**
 * JFrog Artifactory product you want to install into an AMI.
 *
 * @schema CfnModulePropsParametersArtifactoryProduct
 */
export interface CfnModulePropsParametersArtifactoryProduct {
    /**
     * @schema CfnModulePropsParametersArtifactoryProduct#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersArtifactoryProduct#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersArtifactoryProduct' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersArtifactoryProduct(obj: CfnModulePropsParametersArtifactoryProduct | undefined): Record<string, any> | undefined;
/**
 * Version of Artifactory that you want to deploy into the Quick Start.
 *
 * See the release notes to select the version you want to deploy at https://www.jfrog.com/confluence/display/RTF/Release+Notes.
 *
 * @schema CfnModulePropsParametersArtifactoryVersion
 */
export interface CfnModulePropsParametersArtifactoryVersion {
    /**
     * @schema CfnModulePropsParametersArtifactoryVersion#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersArtifactoryVersion#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersArtifactoryVersion' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersArtifactoryVersion(obj: CfnModulePropsParametersArtifactoryVersion | undefined): Record<string, any> | undefined;
/**
 * Secret name created in AWS Secrets Manager, which contains the Artifactory licenses.
 *
 * @schema CfnModulePropsParametersSmLicenseName
 */
export interface CfnModulePropsParametersSmLicenseName {
    /**
     * @schema CfnModulePropsParametersSmLicenseName#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersSmLicenseName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersSmLicenseName' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersSmLicenseName(obj: CfnModulePropsParametersSmLicenseName | undefined): Record<string, any> | undefined;
/**
 * Secret name created in AWS Secrets Manager, which contains the SSL certificate and certificate key.
 *
 * @schema CfnModulePropsParametersSmCertName
 */
export interface CfnModulePropsParametersSmCertName {
    /**
     * @schema CfnModulePropsParametersSmCertName#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersSmCertName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersSmCertName' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersSmCertName(obj: CfnModulePropsParametersSmCertName | undefined): Record<string, any> | undefined;
/**
 * Name of your Artifactory server.
 *
 * Ensure that this matches your certificate.
 *
 * @schema CfnModulePropsParametersArtifactoryServerName
 */
export interface CfnModulePropsParametersArtifactoryServerName {
    /**
     * @schema CfnModulePropsParametersArtifactoryServerName#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersArtifactoryServerName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersArtifactoryServerName' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersArtifactoryServerName(obj: CfnModulePropsParametersArtifactoryServerName | undefined): Record<string, any> | undefined;
/**
 * Master key for the Artifactory cluster.
 *
 * Generate a master key by using the command '$openssl rand -hex 16'.
 *
 * @schema CfnModulePropsParametersMasterKey
 */
export interface CfnModulePropsParametersMasterKey {
    /**
     * @schema CfnModulePropsParametersMasterKey#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersMasterKey#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersMasterKey' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersMasterKey(obj: CfnModulePropsParametersMasterKey | undefined): Record<string, any> | undefined;
/**
 * Set Java options to pass to the JVM for Artifactory.
 *
 * For more information, see the Artifactory system requirements at https://www.jfrog.com/confluence/display/RTF/System+Requirements#SystemRequirements-RecommendedHardware. Do not add Xms or Xmx settings without disabling DefaultJavaMemSettings.
 *
 * @schema CfnModulePropsParametersExtraJavaOptions
 */
export interface CfnModulePropsParametersExtraJavaOptions {
    /**
     * @schema CfnModulePropsParametersExtraJavaOptions#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersExtraJavaOptions#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersExtraJavaOptions' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersExtraJavaOptions(obj: CfnModulePropsParametersExtraJavaOptions | undefined): Record<string, any> | undefined;
/**
 * Choose false to overwrite the standard memory-calculation options to pass to the Artifactory JVM.
 *
 * If you plan to overwrite them, ensure they are added to the ExtraJavaOptions to prevent the stack provision from failing.
 *
 * @schema CfnModulePropsParametersDefaultJavaMemSettings
 */
export interface CfnModulePropsParametersDefaultJavaMemSettings {
    /**
     * @schema CfnModulePropsParametersDefaultJavaMemSettings#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDefaultJavaMemSettings#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDefaultJavaMemSettings' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDefaultJavaMemSettings(obj: CfnModulePropsParametersDefaultJavaMemSettings | undefined): Record<string, any> | undefined;
/**
 * Name of your database instance.
 *
 * The name must be unique across all instances owned by your AWS account in the current Region. The database instance identifier is case-insensitive, but it's stored in lowercase (as in "mydbinstance").
 *
 * @schema CfnModulePropsParametersDatabaseName
 */
export interface CfnModulePropsParametersDatabaseName {
    /**
     * @schema CfnModulePropsParametersDatabaseName#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabaseName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabaseName' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabaseName(obj: CfnModulePropsParametersDatabaseName | undefined): Record<string, any> | undefined;
/**
 * Database engine that you want to run, which is currently locked to MySQL.
 *
 * @schema CfnModulePropsParametersDatabaseEngine
 */
export interface CfnModulePropsParametersDatabaseEngine {
    /**
     * @schema CfnModulePropsParametersDatabaseEngine#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabaseEngine#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabaseEngine' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabaseEngine(obj: CfnModulePropsParametersDatabaseEngine | undefined): Record<string, any> | undefined;
/**
 * Login ID for the master user of your database instance.
 *
 * @schema CfnModulePropsParametersDatabaseUser
 */
export interface CfnModulePropsParametersDatabaseUser {
    /**
     * @schema CfnModulePropsParametersDatabaseUser#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabaseUser#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabaseUser' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabaseUser(obj: CfnModulePropsParametersDatabaseUser | undefined): Record<string, any> | undefined;
/**
 * Password for the Artifactory database user.
 *
 * @schema CfnModulePropsParametersDatabasePassword
 */
export interface CfnModulePropsParametersDatabasePassword {
    /**
     * @schema CfnModulePropsParametersDatabasePassword#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabasePassword#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabasePassword' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabasePassword(obj: CfnModulePropsParametersDatabasePassword | undefined): Record<string, any> | undefined;
/**
 * Size of the database to be deployed as part of the Quick Start.
 *
 * @schema CfnModulePropsParametersDatabaseInstance
 */
export interface CfnModulePropsParametersDatabaseInstance {
    /**
     * @schema CfnModulePropsParametersDatabaseInstance#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabaseInstance#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabaseInstance' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabaseInstance(obj: CfnModulePropsParametersDatabaseInstance | undefined): Record<string, any> | undefined;
/**
 * Size in gigabytes of the available storage for the database instance.
 *
 * @schema CfnModulePropsParametersDatabaseAllocatedStorage
 */
export interface CfnModulePropsParametersDatabaseAllocatedStorage {
    /**
     * @schema CfnModulePropsParametersDatabaseAllocatedStorage#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabaseAllocatedStorage#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabaseAllocatedStorage' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabaseAllocatedStorage(obj: CfnModulePropsParametersDatabaseAllocatedStorage | undefined): Record<string, any> | undefined;
/**
 * Preferred availability zone for Amazon RDS primary instance.
 *
 * @schema CfnModulePropsParametersDatabasePreferredAz
 */
export interface CfnModulePropsParametersDatabasePreferredAz {
    /**
     * @schema CfnModulePropsParametersDatabasePreferredAz#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersDatabasePreferredAz#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersDatabasePreferredAz' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersDatabasePreferredAz(obj: CfnModulePropsParametersDatabasePreferredAz | undefined): Record<string, any> | undefined;
/**
 * Choose false to create an Amazon RDS instance in a single Availability Zone.
 *
 * @schema CfnModulePropsParametersMultiAzDatabase
 */
export interface CfnModulePropsParametersMultiAzDatabase {
    /**
     * @schema CfnModulePropsParametersMultiAzDatabase#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersMultiAzDatabase#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersMultiAzDatabase' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersMultiAzDatabase(obj: CfnModulePropsParametersMultiAzDatabase | undefined): Record<string, any> | undefined;
/**
 * S3 bucket name for the Quick Start assets.
 *
 * This string can include numbers, lowercase letters, and hyphens (-). It cannot start or end with a hyphen (-).
 *
 * @schema CfnModulePropsParametersQsS3BucketName
 */
export interface CfnModulePropsParametersQsS3BucketName {
    /**
     * @schema CfnModulePropsParametersQsS3BucketName#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersQsS3BucketName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersQsS3BucketName' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersQsS3BucketName(obj: CfnModulePropsParametersQsS3BucketName | undefined): Record<string, any> | undefined;
/**
 * S3 key prefix for the Quick Start assets.
 *
 * Quick Start key prefix can include numbers, lowercase letters, uppercase letters, hyphens (-), and forward slash (/).
 *
 * @schema CfnModulePropsParametersQsS3KeyPrefix
 */
export interface CfnModulePropsParametersQsS3KeyPrefix {
    /**
     * @schema CfnModulePropsParametersQsS3KeyPrefix#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersQsS3KeyPrefix#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersQsS3KeyPrefix' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersQsS3KeyPrefix(obj: CfnModulePropsParametersQsS3KeyPrefix | undefined): Record<string, any> | undefined;
/**
 * AWS Region where the Quick Start S3 bucket (QSS3BucketName) is hosted.
 *
 * If you use your own bucket, you must specify your own value.
 *
 * @schema CfnModulePropsParametersQsS3BucketRegion
 */
export interface CfnModulePropsParametersQsS3BucketRegion {
    /**
     * @schema CfnModulePropsParametersQsS3BucketRegion#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersQsS3BucketRegion#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersQsS3BucketRegion' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersQsS3BucketRegion(obj: CfnModulePropsParametersQsS3BucketRegion | undefined): Record<string, any> | undefined;
/**
 * Choose true to install JFrog Xray instance(s).
 *
 * @schema CfnModulePropsParametersInstallXray
 */
export interface CfnModulePropsParametersInstallXray {
    /**
     * @schema CfnModulePropsParametersInstallXray#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersInstallXray#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersInstallXray' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersInstallXray(obj: CfnModulePropsParametersInstallXray | undefined): Record<string, any> | undefined;
/**
 * The version of Xray that you want to deploy into the Quick Start.
 *
 * @schema CfnModulePropsParametersXrayVersion
 */
export interface CfnModulePropsParametersXrayVersion {
    /**
     * @schema CfnModulePropsParametersXrayVersion#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersXrayVersion#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersXrayVersion' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersXrayVersion(obj: CfnModulePropsParametersXrayVersion | undefined): Record<string, any> | undefined;
/**
 * The number of Xray instances servers to complete your HA deployment.
 *
 * The minimum number is one; the maximum is seven. Do not select more than instances than you have licenses for.
 *
 * @schema CfnModulePropsParametersXrayNumberOfInstances
 */
export interface CfnModulePropsParametersXrayNumberOfInstances {
    /**
     * @schema CfnModulePropsParametersXrayNumberOfInstances#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersXrayNumberOfInstances#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersXrayNumberOfInstances' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersXrayNumberOfInstances(obj: CfnModulePropsParametersXrayNumberOfInstances | undefined): Record<string, any> | undefined;
/**
 * The EC2 instance type for the Xray instances.
 *
 * @schema CfnModulePropsParametersXrayInstanceType
 */
export interface CfnModulePropsParametersXrayInstanceType {
    /**
     * @schema CfnModulePropsParametersXrayInstanceType#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersXrayInstanceType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersXrayInstanceType' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersXrayInstanceType(obj: CfnModulePropsParametersXrayInstanceType | undefined): Record<string, any> | undefined;
/**
 * The login ID for the Xray database user.
 *
 * @schema CfnModulePropsParametersXrayDatabaseUser
 */
export interface CfnModulePropsParametersXrayDatabaseUser {
    /**
     * @schema CfnModulePropsParametersXrayDatabaseUser#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersXrayDatabaseUser#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersXrayDatabaseUser' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersXrayDatabaseUser(obj: CfnModulePropsParametersXrayDatabaseUser | undefined): Record<string, any> | undefined;
/**
 * The password for the Xray database user.
 *
 * @schema CfnModulePropsParametersXrayDatabasePassword
 */
export interface CfnModulePropsParametersXrayDatabasePassword {
    /**
     * @schema CfnModulePropsParametersXrayDatabasePassword#Type
     */
    readonly type: string;
    /**
     * @schema CfnModulePropsParametersXrayDatabasePassword#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnModulePropsParametersXrayDatabasePassword' to JSON representation.
 */
export declare function toJson_CfnModulePropsParametersXrayDatabasePassword(obj: CfnModulePropsParametersXrayDatabasePassword | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesBastionStack
 */
export interface CfnModulePropsResourcesBastionStack {
    /**
     * @schema CfnModulePropsResourcesBastionStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesBastionStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesBastionStack' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesBastionStack(obj: CfnModulePropsResourcesBastionStack | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryCoreInfraStack
 */
export interface CfnModulePropsResourcesArtifactoryCoreInfraStack {
    /**
     * @schema CfnModulePropsResourcesArtifactoryCoreInfraStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryCoreInfraStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryCoreInfraStack' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryCoreInfraStack(obj: CfnModulePropsResourcesArtifactoryCoreInfraStack | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryElb
 */
export interface CfnModulePropsResourcesArtifactoryElb {
    /**
     * @schema CfnModulePropsResourcesArtifactoryElb#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryElb#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryElb' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryElb(obj: CfnModulePropsResourcesArtifactoryElb | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactorySslTargetGroup
 */
export interface CfnModulePropsResourcesArtifactorySslTargetGroup {
    /**
     * @schema CfnModulePropsResourcesArtifactorySslTargetGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactorySslTargetGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactorySslTargetGroup' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactorySslTargetGroup(obj: CfnModulePropsResourcesArtifactorySslTargetGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryTargetGroup
 */
export interface CfnModulePropsResourcesArtifactoryTargetGroup {
    /**
     * @schema CfnModulePropsResourcesArtifactoryTargetGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryTargetGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryTargetGroup' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryTargetGroup(obj: CfnModulePropsResourcesArtifactoryTargetGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactorySslElbListener
 */
export interface CfnModulePropsResourcesArtifactorySslElbListener {
    /**
     * @schema CfnModulePropsResourcesArtifactorySslElbListener#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactorySslElbListener#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactorySslElbListener' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactorySslElbListener(obj: CfnModulePropsResourcesArtifactorySslElbListener | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryElbListener
 */
export interface CfnModulePropsResourcesArtifactoryElbListener {
    /**
     * @schema CfnModulePropsResourcesArtifactoryElbListener#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryElbListener#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryElbListener' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryElbListener(obj: CfnModulePropsResourcesArtifactoryElbListener | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryInternalElb
 */
export interface CfnModulePropsResourcesArtifactoryInternalElb {
    /**
     * @schema CfnModulePropsResourcesArtifactoryInternalElb#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryInternalElb#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryInternalElb' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryInternalElb(obj: CfnModulePropsResourcesArtifactoryInternalElb | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryInternalTargetGroup
 */
export interface CfnModulePropsResourcesArtifactoryInternalTargetGroup {
    /**
     * @schema CfnModulePropsResourcesArtifactoryInternalTargetGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryInternalTargetGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryInternalTargetGroup' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryInternalTargetGroup(obj: CfnModulePropsResourcesArtifactoryInternalTargetGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryInternalElbListener
 */
export interface CfnModulePropsResourcesArtifactoryInternalElbListener {
    /**
     * @schema CfnModulePropsResourcesArtifactoryInternalElbListener#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryInternalElbListener#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryInternalElbListener' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryInternalElbListener(obj: CfnModulePropsResourcesArtifactoryInternalElbListener | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryEc2Sg
 */
export interface CfnModulePropsResourcesArtifactoryEc2Sg {
    /**
     * @schema CfnModulePropsResourcesArtifactoryEc2Sg#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryEc2Sg#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryEc2Sg' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryEc2Sg(obj: CfnModulePropsResourcesArtifactoryEc2Sg | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryHostRole
 */
export interface CfnModulePropsResourcesArtifactoryHostRole {
    /**
     * @schema CfnModulePropsResourcesArtifactoryHostRole#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryHostRole#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryHostRole' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryHostRole(obj: CfnModulePropsResourcesArtifactoryHostRole | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryHostProfile
 */
export interface CfnModulePropsResourcesArtifactoryHostProfile {
    /**
     * @schema CfnModulePropsResourcesArtifactoryHostProfile#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryHostProfile#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryHostProfile' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryHostProfile(obj: CfnModulePropsResourcesArtifactoryHostProfile | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactoryPrimary
 */
export interface CfnModulePropsResourcesArtifactoryPrimary {
    /**
     * @schema CfnModulePropsResourcesArtifactoryPrimary#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactoryPrimary#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactoryPrimary' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactoryPrimary(obj: CfnModulePropsResourcesArtifactoryPrimary | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesArtifactorySecondary
 */
export interface CfnModulePropsResourcesArtifactorySecondary {
    /**
     * @schema CfnModulePropsResourcesArtifactorySecondary#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesArtifactorySecondary#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesArtifactorySecondary' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesArtifactorySecondary(obj: CfnModulePropsResourcesArtifactorySecondary | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesXrayHostRole
 */
export interface CfnModulePropsResourcesXrayHostRole {
    /**
     * @schema CfnModulePropsResourcesXrayHostRole#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesXrayHostRole#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesXrayHostRole' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesXrayHostRole(obj: CfnModulePropsResourcesXrayHostRole | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesXrayHostProfile
 */
export interface CfnModulePropsResourcesXrayHostProfile {
    /**
     * @schema CfnModulePropsResourcesXrayHostProfile#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesXrayHostProfile#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesXrayHostProfile' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesXrayHostProfile(obj: CfnModulePropsResourcesXrayHostProfile | undefined): Record<string, any> | undefined;
/**
 * @schema CfnModulePropsResourcesXrayExistingVpcStack
 */
export interface CfnModulePropsResourcesXrayExistingVpcStack {
    /**
     * @schema CfnModulePropsResourcesXrayExistingVpcStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnModulePropsResourcesXrayExistingVpcStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnModulePropsResourcesXrayExistingVpcStack' to JSON representation.
 */
export declare function toJson_CfnModulePropsResourcesXrayExistingVpcStack(obj: CfnModulePropsResourcesXrayExistingVpcStack | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `JFrog::Artifactory::ExistingVpc::MODULE`.
 *
 * @external
 * @cloudformationResource JFrog::Artifactory::ExistingVpc::MODULE
 * @link http://unknown-url
 */
export declare class CfnModule extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     *
     * @external
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "JFrog::Artifactory::ExistingVpc::MODULE";
    /**
     * Resource props.
     *
     * @external
     */
    readonly props: CfnModuleProps;
    /**
     * Create a new `JFrog::Artifactory::ExistingVpc::MODULE`.
     *
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     * @external
     */
    constructor(scope: cdk.Construct, id: string, props: CfnModuleProps);
}
